==> cdktf-cdktf-provider-upcloud-0.0.14.tar.gz: package/lib/loadbalancer-dynamic-backend-member.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface LoadbalancerDynamicBackendMemberConfig extends cdktf.TerraformMetaArguments {
    /**
    * ID of the load balancer backend to which the member is connected.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_dynamic_backend_member#backend LoadbalancerDynamicBackendMember#backend}
    */
    readonly backend: string;
    /**
    * Indicates if the member is enabled. Disabled members are excluded from load balancing.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_dynamic_backend_member#enabled LoadbalancerDynamicBackendMember#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Optional fallback IP address in case of failure on DNS resolving.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_dynamic_backend_member#ip LoadbalancerDynamicBackendMember#ip}
    */
    readonly ip?: string;
    /**
    * Maximum number of sessions before queueing.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_dynamic_backend_member#max_sessions LoadbalancerDynamicBackendMember#max_sessions}
    */
    readonly maxSessions: number;
    /**
    * The name of the member must be unique within the load balancer backend service.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_dynamic_backend_member#name LoadbalancerDynamicBackendMember#name}
    */
    readonly name: string;
    /**
    * Server port. Port is optional and can be specified in DNS SRV record.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_dynamic_backend_member#port LoadbalancerDynamicBackendMember#port}
    */
    readonly port?: number;
    /**
    * Used to adjust the server's weight relative to other servers.
                  All servers will receive a load proportional to their weight relative to the sum of all weights, so the higher the weight, the higher the load.
                  A value of 0 means the server will not participate in load balancing but will still accept persistent connections.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_dynamic_backend_member#weight LoadbalancerDynamicBackendMember#weight}
    */
    readonly weight: number;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_dynamic_backend_member upcloud_loadbalancer_dynamic_backend_member}
*/
export declare class LoadbalancerDynamicBackendMember extends cdktf.TerraformResource {
    static readonly tfResourceType = "upcloud_loadbalancer_dynamic_backend_member";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_dynamic_backend_member upcloud_loadbalancer_dynamic_backend_member} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options LoadbalancerDynamicBackendMemberConfig
    */
    constructor(scope: Construct, id: string, config: LoadbalancerDynamicBackendMemberConfig);
    private _backend?;
    get backend(): string;
    set backend(value: string);
    get backendInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    get id(): string;
    private _ip?;
    get ip(): string;
    set ip(value: string);
    resetIp(): void;
    get ipInput(): string | undefined;
    private _maxSessions?;
    get maxSessions(): number;
    set maxSessions(value: number);
    get maxSessionsInput(): number | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    resetPort(): void;
    get portInput(): number | undefined;
    private _weight?;
    get weight(): number;
    set weight(value: number);
    get weightInput(): number | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
//# sourceMappingURL=loadbalancer-dynamic-backend-member.d.ts.map

==> cdktf-cdktf-provider-upcloud-0.1.6.tar.gz: package/lib/loadbalancer-dynamic-backend-member.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface LoadbalancerDynamicBackendMemberConfig extends cdktf.TerraformMetaArguments {
    /**
    * ID of the load balancer backend to which the member is connected.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_dynamic_backend_member#backend LoadbalancerDynamicBackendMember#backend}
    */
    readonly backend: string;
    /**
    * Indicates if the member is enabled. Disabled members are excluded from load balancing.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_dynamic_backend_member#enabled LoadbalancerDynamicBackendMember#enabled}
    */
    readonly enabled?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_dynamic_backend_member#id LoadbalancerDynamicBackendMember#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Optional fallback IP address in case of failure on DNS resolving.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_dynamic_backend_member#ip LoadbalancerDynamicBackendMember#ip}
    */
    readonly ip?: string;
    /**
    * Maximum number of sessions before queueing.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_dynamic_backend_member#max_sessions LoadbalancerDynamicBackendMember#max_sessions}
    */
    readonly maxSessions: number;
    /**
    * The name of the member must be unique within the load balancer backend service.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_dynamic_backend_member#name LoadbalancerDynamicBackendMember#name}
    */
    readonly name: string;
    /**
    * Server port. Port is optional and can be specified in DNS SRV record.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_dynamic_backend_member#port LoadbalancerDynamicBackendMember#port}
    */
    readonly port?: number;
    /**
    * Used to adjust the server's weight relative to other servers.
                  All servers will receive a load proportional to their weight relative to the sum of all weights, so the higher the weight, the higher the load.
                  A value of 0 means the server will not participate in load balancing but will still accept persistent connections.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_dynamic_backend_member#weight LoadbalancerDynamicBackendMember#weight}
    */
    readonly weight: number;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_dynamic_backend_member upcloud_loadbalancer_dynamic_backend_member}
*/
export declare class LoadbalancerDynamicBackendMember extends cdktf.TerraformResource {
    static readonly tfResourceType = "upcloud_loadbalancer_dynamic_backend_member";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/upcloud/r/loadbalancer_dynamic_backend_member upcloud_loadbalancer_dynamic_backend_member} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options LoadbalancerDynamicBackendMemberConfig
    */
    constructor(scope: Construct, id: string, config: LoadbalancerDynamicBackendMemberConfig);
    private _backend?;
    get backend(): string;
    set backend(value: string);
    get backendInput(): string | undefined;
    private _enabled?;
    get enabled(): boolean | cdktf.IResolvable;
    set enabled(value: boolean | cdktf.IResolvable);
    resetEnabled(): void;
    get enabledInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _ip?;
    get ip(): string;
    set ip(value: string);
    resetIp(): void;
    get ipInput(): string | undefined;
    private _maxSessions?;
    get maxSessions(): number;
    set maxSessions(value: number);
    get maxSessionsInput(): number | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _port?;
    get port(): number;
    set port(value: number);
    resetPort(): void;
    get portInput(): number | undefined;
    private _weight?;
    get weight(): number;
    set weight(value: number);
    get weightInput(): number | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
//# sourceMappingURL=loadbalancer-dynamic-backend-member.d.ts.map
